==> svm-19.2.0-sources.jar: com/oracle/svm/core/graal/nodes/CInterfaceWriteNode.java <==
/*
 * Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodes.ValueNode;
import org.graalvm.compiler.nodes.memory.WriteNode;
import org.graalvm.compiler.nodes.memory.address.AddressNode;
import org.graalvm.word.LocationIdentity;

/**
 * Writes a C memory location. The only addition is that we have a human-readable name for debugging
 * purposes.
 */
@NodeInfo(nameTemplate = "write#{p#accessName/s}")
public class CInterfaceWriteNode extends WriteNode {
    public static final NodeClass<CInterfaceWriteNode> TYPE = NodeClass.create(CInterfaceWriteNode.class);

    protected final String accessName;

    public CInterfaceWriteNode(AddressNode address, LocationIdentity locationIdentity, ValueNode value, BarrierType barrierType, String accessName) {
        super(TYPE, address, locationIdentity, value, barrierType);
        this.accessName = accessName;
    }
}

==> svm-22.0.0-sources.jar: com/oracle/svm/core/graal/nodes/CInterfaceWriteNode.java <==
/*
 * Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.core.graal.nodes;

import org.graalvm.compiler.graph.NodeClass;
import org.graalvm.compiler.nodeinfo.NodeInfo;
import org.graalvm.compiler.nodes.ValueNode;
import org.graalvm.compiler.nodes.memory.WriteNode;
import org.graalvm.compiler.nodes.memory.address.AddressNode;
import org.graalvm.word.LocationIdentity;

/**
 * Writes a C memory location. The only addition is that we have a human-readable name for debugging
 * purposes.
 */
@NodeInfo(nameTemplate = "write#{p#accessName/s}")
public class CInterfaceWriteNode extends WriteNode {
    public static final NodeClass<CInterfaceWriteNode> TYPE = NodeClass.create(CInterfaceWriteNode.class);

    protected final String accessName;

    public CInterfaceWriteNode(AddressNode address, LocationIdentity locationIdentity, ValueNode value, BarrierType barrierType, String accessName) {
        super(TYPE, address, locationIdentity, locationIdentity, value, barrierType);
        this.accessName = accessName;
    }
}
